Documentation
¶
Index ¶
Constants ¶
const CoreFeatures = api.CoreFeatureSIMD | api.CoreFeatureBulkMemoryOperations | api.CoreFeatureNonTrappingFloatToIntConversion | api.CoreFeatureMutableGlobal | api.CoreFeatureReferenceTypes | api.CoreFeatureSignExtensionOps | experimental.CoreFeaturesTailCall
CoreFeatures are the WebAssembly Core specification features our embedded binaries are compiled with.
Variables ¶
This section is empty.
Functions ¶
func NewRuntime ¶ added in v0.4.1
NewRuntime returns a new WebAssembly wazero.Runtime compatible with go-ffmpreg.
Types ¶
type Args ¶
type Args struct {
// Program name, depending on the
// module being run this may or may
// not be necessary.
Name string
// Optional further module configuration function.
// (e.g. to mount filesystem dir, set env vars, etc).
Config func(wazero.ModuleConfig) wazero.ModuleConfig
// Standard FDs.
Stdin io.Reader
Stdout io.Writer
Stderr io.Writer
// CLI args.
Args []string
}
Args encompasses a common set of configuration options often passed to wazero.Runtime on module instantiation.
Click to show internal directories.
Click to hide internal directories.